@@ -44,13 +44,16 @@ Components.utils.import("resource://app/modules/virtualFolderWrapper.js");
  * Do initialization for xpcshell-tests; not used by
  *  test-folder-display-helpers.js, our friendly mozmill test helper.
  */
-function initViewWrapperTestUtils() {
+function initViewWrapperTestUtils(aInjectionConfig) {
   gMessageGenerator = new MessageGenerator();
   gMessageScenarioFactory = new MessageScenarioFactory(gMessageGenerator);
 
   async_test_runner_register_helper(VWTU_testHelper);
   register_message_injection_listener(VWTU_testHelper);
-  configure_message_injection({mode: "local"});
+  if (aInjectionConfig)
+    configure_message_injection(aInjectionConfig);
+  else
+    configure_message_injection({mode: "local"});
 }
 
 // something less sucky than do_check_true
@@ -283,8 +286,10 @@ function async_view_end_update(aViewWrapper) {
  *  so code can look clean.
  *
  * @param aViewWrapper Required when you want us to operate asynchronously.
+ * @param aDontEmptyTrash This function will empty the trash after deleting the
+ *                        folder, unless you set this parameter to true.
  */
-function async_delete_folder(aFolder, aViewWrapper) {
+function async_delete_folder(aFolder, aViewWrapper, aDontEmptyTrash) {
   VWTU_testHelper.active_real_folders.splice(
     VWTU_testHelper.active_real_folders.indexOf(aFolder), 1);
   // deleting tries to be helpful and move the folder to the trash...
@@ -309,7 +314,8 @@ function async_delete_folder(aFolder, aViewWrapper) {
   // ...so now the stupid folder is in the stupid trash
   // let's empty the trash, then, shall we?
   // (for local folders it doesn't matter who we call this on.)
-  aFolder.emptyTrash(null, null);
+  if (!aDontEmptyTrash)
+    aFolder.emptyTrash(null, null);
   return false;
 }
 var delete_folder = async_delete_folder;
