@@ -480,7 +480,7 @@ nsMsgComposeService::GetOrigWindowSelection(MSG_ComposeType type, nsIMsgWindow *
   nsCAutoString charsOnlyIf;
   prefs->GetBoolPref(PREF_MAILNEWS_REPLY_QUOTING_SELECTION_MULTI_WORD, &requireMultipleWords);
   prefs->GetCharPref(PREF_MAILNEWS_REPLY_QUOTING_SELECTION_ONLY_IF, getter_Copies(charsOnlyIf));
-  if (sel && requireMultipleWords || !charsOnlyIf.IsEmpty())
+  if (sel && (requireMultipleWords || !charsOnlyIf.IsEmpty()))
   {
     nsAutoString selPlain;
     rv = sel->ToString(getter_Copies(selPlain));
@@ -1617,9 +1617,13 @@ nsMsgComposeService::Handle(nsICommandLine* aCmdLine)
   if (count > found + 1) {
     aCmdLine->GetArgument(found + 1, uristr);
     if (StringBeginsWith(uristr, NS_LITERAL_STRING("mailto:"))  ||
+        StringBeginsWith(uristr, NS_LITERAL_STRING("preselectid=")) ||
         StringBeginsWith(uristr, NS_LITERAL_STRING("to="))  ||
         StringBeginsWith(uristr, NS_LITERAL_STRING("cc="))  ||
+        StringBeginsWith(uristr, NS_LITERAL_STRING("bcc=")) ||
+        StringBeginsWith(uristr, NS_LITERAL_STRING("newsgroups=")) ||
         StringBeginsWith(uristr, NS_LITERAL_STRING("subject=")) ||
+        StringBeginsWith(uristr, NS_LITERAL_STRING("format=")) ||
         StringBeginsWith(uristr, NS_LITERAL_STRING("body="))  ||
         StringBeginsWith(uristr, NS_LITERAL_STRING("attachment="))) {
       composeShouldHandle = PR_TRUE; // the -url argument looks like mailto
