@@ -306,11 +306,16 @@ NS_IMETHODIMP nsPNGDecoder::Init(imgILoad *aLoad)
       return NS_ERROR_OUT_OF_MEMORY;
       
     mImageLoad->SetImage(mImage);
-    if (NS_FAILED(mImage->SetDiscardable("image/png"))) {
-      PR_LOG(gPNGDecoderAccountingLog, PR_LOG_DEBUG,
-             ("PNGDecoderAccounting: info_callback(): failed to set image container %p as discardable",
-              mImage.get()));
-      return NS_ERROR_FAILURE;
+
+    // Don't discard if we're multipart, and assume we are for safety.
+    PRBool multipart = PR_TRUE;
+    if (NS_SUCCEEDED(mImageLoad->GetIsMultiPartChannel(&multipart)) && !multipart) {
+      if (NS_FAILED(mImage->SetDiscardable("image/png"))) {
+        PR_LOG(gPNGDecoderAccountingLog, PR_LOG_DEBUG,
+               ("PNGDecoderAccounting: info_callback(): failed to set image container %p as discardable",
+                mImage.get()));
+        return NS_ERROR_FAILURE;
+      }
     }
   }
 
@@ -777,6 +782,11 @@ row_callback(png_structp png_ptr, png_bytep new_row,
   if (decoder->mFrameIsHidden)
     return;
 
+  PRInt32 height;
+  decoder->mFrame->GetHeight(&height);
+  if (row_num >= height)
+    return;
+
   if (new_row) {
     PRInt32 width;
     decoder->mFrame->GetWidth(&width);
